@@ -14,9 +14,12 @@
 #include <QAudioDeviceInfo>
 #include <QAudioOutput>
 #include <QTimer>
-#include <QQmlEngine>
+#include <QMap>
 #include "preset.h"
 
+class QQmlEngine;
+class QJSEngine;
+
 class Generator;
 
 class GSynth : public QObject
@@ -24,7 +27,7 @@ class GSynth : public QObject
     Q_OBJECT
 
 public:
-    explicit GSynth(QObject *parent = 0);
+    explicit GSynth(QObject *parent = nullptr);
     virtual ~GSynth();
 
     /**
@@ -48,7 +51,7 @@ public:
 protected:
     static GSynth *m_instance;
 
-private slots:
+private Q_SLOTS:
     void stopAudio(int note);
     
 private:
