@@ -8,9 +8,10 @@
  *   SPDX-License-Identifier: GPL-3.0-or-later
  */
 
-#include <QtTest>
+#include <QTest>
 #include <QObject>
 #include <QFile>
+#include <QSignalSpy>
 
 #include "src/core/ApplicationSettings.h"
 #include "ApplicationSettingsMock.h"
@@ -64,7 +65,6 @@ void CoreApplicationSettingsTest::ApplicationSettingsTest_data()
     QTest::addColumn<quint32>("filterLevelMax");
     QTest::addColumn<bool>("isKioskMode");
     QTest::addColumn<bool>("sectionVisible");
-    QTest::addColumn<QString>("wordset");
     QTest::addColumn<QString>("downloadServerUrl");
     QTest::addColumn<QString>("cachePath");
     QTest::addColumn<QString>("userDataPath");
@@ -78,8 +78,8 @@ void CoreApplicationSettingsTest::ApplicationSettingsTest_data()
     QTest::addColumn<qreal>("audioEffectsVolume");
     QTest::addColumn<QStringList>("filteredBackgroundMusic");
     
-    QTest::newRow("dummySettings1") << true << true << true << (quint32)21 << (quint32)25 << true << "en_EN" << "font1" << true << (quint32)36 << (qreal)2.532 << true << (quint32)26 << (quint32)84 << true << true << "wordset1" << "downloadServerUrl1" << "cachePath1" << "userDataPath1" << (quint32)48 << true << 7 << 52 << false << "softwareRenderer" << (qreal)0.5 << (qreal)0.7 << (QStringList() << "music1");
-    QTest::newRow("dummySettings2") << false << false << false << (quint32)20 << (quint32)32 << false << "en_US" << "font2" << false << (quint32)34 <<(qreal)2.3 << false << (quint32)24 << (quint32)80 << false << false << "wordset2" << "downloadServerUrl2" << "cachePath2" << "userDataPath2" << (quint32)44 << false << 5 << 64 << false << "openglRenderer" << (qreal)1.0 << (qreal)0.0 << (QStringList() << "music2" << "music3");
+    QTest::newRow("dummySettings1") << true << true << true << (quint32)21 << (quint32)25 << true << "en_EN" << "font1" << true << (quint32)36 << (qreal)2.532 << true << (quint32)26 << (quint32)84 << true << true << "downloadServerUrl1" << "cachePath1" << "userDataPath1" << (quint32)48 << true << 7 << 52 << false << "softwareRenderer" << (qreal)0.5 << (qreal)0.7 << (QStringList() << "music1");
+    QTest::newRow("dummySettings2") << false << false << false << (quint32)20 << (quint32)32 << false << "en_US" << "font2" << false << (quint32)34 <<(qreal)2.3 << false << (quint32)24 << (quint32)80 << false << false << "downloadServerUrl2" << "cachePath2" << "userDataPath2" << (quint32)44 << false << 5 << 64 << false << "openglRenderer" << (qreal)1.0 << (qreal)0.0 << (QStringList() << "music2" << "music3");
 }
 
 void CoreApplicationSettingsTest::ApplicationSettingsTest()
@@ -103,7 +103,6 @@ void CoreApplicationSettingsTest::ApplicationSettingsTest()
     APPLICATION_SETTINGS_TEST_ATTRIBUTE(quint32, filterLevelMax, setFilterLevelMax, filterLevelMaxChanged);
     APPLICATION_SETTINGS_TEST_ATTRIBUTE(bool, isKioskMode, setKioskMode, kioskModeChanged);
     APPLICATION_SETTINGS_TEST_ATTRIBUTE(bool, sectionVisible, setSectionVisible, sectionVisibleChanged);
-    APPLICATION_SETTINGS_TEST_ATTRIBUTE(QString, wordset, setWordset, wordsetChanged);
     APPLICATION_SETTINGS_TEST_ATTRIBUTE(QString, downloadServerUrl, setDownloadServerUrl, downloadServerUrlChanged);
     APPLICATION_SETTINGS_TEST_ATTRIBUTE(QString, cachePath, setCachePath, cachePathChanged);
     APPLICATION_SETTINGS_TEST_ATTRIBUTE(QString, userDataPath, setUserDataPath, userDataPathChanged);
